==> gwenview-trinity-3.5.13.2.tar.xz: gwenview-trinity-3.5.13.2/src/gvcore/imageviewcontroller.h <==
// vim: set tabstop=4 shiftwidth=4 noexpandtab
/*
Gwenview - A simple image viewer for KDE
Copyright 2006 Aurélien Gâteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/
#ifndef IMAGEVIEWCONTROLLER_H
#define IMAGEVIEWCONTROLLER_H   

// TQt
#include <tqobject.h>

// KDE
#include <kaction.h>

// Local
#include "libgwenview_export.h"

class TQPoint;
class TQWidget;

class KToolBar;

namespace Gwenview {


class Document;
class ImageView;


class LIBGWENVIEW_EXPORT ImageViewController : public TQObject {
Q_OBJECT
  TQ_OBJECT
public:
	ImageViewController(TQWidget* parent, Document*, KActionCollection*);
	~ImageViewController();
	
	TQWidget* widget() const;
	
	void setImageViewActions(const KActionPtrList&);

	void setFullScreen(bool);
	void setNormalCommonActions(const KActionPtrList&);
	void setFullScreenCommonActions(const KActionPtrList&);
	void setFocus();

protected:
	virtual bool eventFilter(TQObject*, TQEvent*);

public slots:
	void updateFromSettings();

signals:
	void requestHintDisplay(const TQString&);
	void selectPrevious();
	void selectNext();
	void doubleClicked();

private slots:
	void slotLoaded();
	void openImageViewContextMenu(const TQPoint&);
	void slotAutoHide();

private:
	struct Private;
	Private* d;
};

} // namespace

#endif /* IMAGEVIEWCONTROLLER_H */

==> gwenview-trinity_14.0.8.orig.tar.xz: gwenview-trinity-14.0.8/src/gvcore/imageviewcontroller.h <==
// vim: set tabstop=4 shiftwidth=4 noexpandtab
/*
Gwenview - A simple image viewer for TDE
Copyright 2006 Aurélien Gâteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/
#ifndef IMAGEVIEWCONTROLLER_H
#define IMAGEVIEWCONTROLLER_H   

// TQt
#include <tqobject.h>

// KDE
#include <tdeaction.h>

// Local
#include "libgwenview_export.h"

class TQPoint;
class TQWidget;

class TDEToolBar;

namespace Gwenview {


class Document;
class ImageView;


class LIBGWENVIEW_EXPORT ImageViewController : public TQObject {
Q_OBJECT
  
public:
	ImageViewController(TQWidget* parent, Document*, TDEActionCollection*);
	~ImageViewController();
	
	TQWidget* widget() const;
	
	void setImageViewActions(const TDEActionPtrList&);

	void setFullScreen(bool);
	void setNormalCommonActions(const TDEActionPtrList&);
	void setFullScreenCommonActions(const TDEActionPtrList&);
	void setFocus();

protected:
	virtual bool eventFilter(TQObject*, TQEvent*);

public slots:
	void updateFromSettings();

signals:
	void requestHintDisplay(const TQString&);
	void selectPrevious();
	void selectNext();
	void doubleClicked();

private slots:
	void slotLoaded();
	void openImageViewContextMenu(const TQPoint&);
	void slotAutoHide();

private:
	struct Private;
	Private* d;
};

} // namespace

#endif /* IMAGEVIEWCONTROLLER_H */
